@@ -15,6 +15,16 @@ from .Data import Data
 
 # Import all class method
 # Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.DataND._set_values import _set_values
+except ImportError as error:
+    _set_values = error
+
+try:
+    from ..Methods.DataND.comp_axes import comp_axes
+except ImportError as error:
+    comp_axes = error
+
 try:
     from ..Methods.DataND.compare_along import compare_along
 except ImportError as error:
@@ -35,21 +45,16 @@ try:
 except ImportError as error:
     compress = error
 
-try:
-    from ..Methods.DataND.set_Ftparameters import set_Ftparameters
-except ImportError as error:
-    set_Ftparameters = error
-
-try:
-    from ..Methods.DataND.comp_axes import comp_axes
-except ImportError as error:
-    comp_axes = error
-
 try:
     from ..Methods.DataND.convert import convert
 except ImportError as error:
     convert = error
 
+try:
+    from ..Methods.DataND.export_along import export_along
+except ImportError as error:
+    export_along = error
+
 try:
     from ..Methods.DataND.extract_slices import extract_slices
 except ImportError as error:
@@ -60,51 +65,11 @@ try:
 except ImportError as error:
     extract_slices_fft = error
 
-try:
-    from ..Methods.DataND.get_field import get_field
-except ImportError as error:
-    get_field = error
-
-try:
-    from ..Methods.DataND.rebuild_symmetries import rebuild_symmetries
-except ImportError as error:
-    rebuild_symmetries = error
-
-try:
-    from ..Methods.DataND.interpolate import interpolate
-except ImportError as error:
-    interpolate = error
-
 try:
     from ..Methods.DataND.get_along import get_along
 except ImportError as error:
     get_along = error
 
-try:
-    from ..Methods.DataND.get_magnitude_along import get_magnitude_along
-except ImportError as error:
-    get_magnitude_along = error
-
-try:
-    from ..Methods.DataND.get_phase_along import get_phase_along
-except ImportError as error:
-    get_phase_along = error
-
-try:
-    from ..Methods.DataND.get_harmonics import get_harmonics
-except ImportError as error:
-    get_harmonics = error
-
-try:
-    from ..Methods.DataND._set_values import _set_values
-except ImportError as error:
-    _set_values = error
-
-try:
-    from ..Methods.DataND.has_period import has_period
-except ImportError as error:
-    has_period = error
-
 try:
     from ..Methods.DataND.get_axes import get_axes
 except ImportError as error:
@@ -115,6 +80,36 @@ try:
 except ImportError as error:
     get_data_along = error
 
+try:
+    from ..Methods.DataND.get_field import get_field
+except ImportError as error:
+    get_field = error
+
+try:
+    from ..Methods.DataND.get_harmonics import get_harmonics
+except ImportError as error:
+    get_harmonics = error
+
+try:
+    from ..Methods.DataND.get_magnitude_along import get_magnitude_along
+except ImportError as error:
+    get_magnitude_along = error
+
+try:
+    from ..Methods.DataND.get_phase_along import get_phase_along
+except ImportError as error:
+    get_phase_along = error
+
+try:
+    from ..Methods.DataND.has_period import has_period
+except ImportError as error:
+    has_period = error
+
+try:
+    from ..Methods.DataND.interpolate import interpolate
+except ImportError as error:
+    interpolate = error
+
 try:
     from ..Methods.DataND.plot_2D_Data import plot_2D_Data
 except ImportError as error:
@@ -125,6 +120,16 @@ try:
 except ImportError as error:
     plot_3D_Data = error
 
+try:
+    from ..Methods.DataND.rebuild_symmetries import rebuild_symmetries
+except ImportError as error:
+    rebuild_symmetries = error
+
+try:
+    from ..Methods.DataND.set_Ftparameters import set_Ftparameters
+except ImportError as error:
+    set_Ftparameters = error
+
 
 from numpy import array, array_equal
 from ._check import InitUnKnowClassError
@@ -136,6 +141,24 @@ class DataND(Data):
     VERSION = 1
 
     # Check ImportError to remove unnecessary dependencies in unused method
+    # cf Methods.DataND._set_values
+    if isinstance(_set_values, ImportError):
+        _set_values = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use DataND method _set_values: " + str(_set_values))
+            )
+        )
+    else:
+        _set_values = _set_values
+    # cf Methods.DataND.comp_axes
+    if isinstance(comp_axes, ImportError):
+        comp_axes = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use DataND method comp_axes: " + str(comp_axes))
+            )
+        )
+    else:
+        comp_axes = comp_axes
     # cf Methods.DataND.compare_along
     if isinstance(compare_along, ImportError):
         compare_along = property(
@@ -180,26 +203,6 @@ class DataND(Data):
         )
     else:
         compress = compress
-    # cf Methods.DataND.set_Ftparameters
-    if isinstance(set_Ftparameters, ImportError):
-        set_Ftparameters = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method set_Ftparameters: " + str(set_Ftparameters)
-                )
-            )
-        )
-    else:
-        set_Ftparameters = set_Ftparameters
-    # cf Methods.DataND.comp_axes
-    if isinstance(comp_axes, ImportError):
-        comp_axes = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use DataND method comp_axes: " + str(comp_axes))
-            )
-        )
-    else:
-        comp_axes = comp_axes
     # cf Methods.DataND.convert
     if isinstance(convert, ImportError):
         convert = property(
@@ -209,6 +212,17 @@ class DataND(Data):
         )
     else:
         convert = convert
+    # cf Methods.DataND.export_along
+    if isinstance(export_along, ImportError):
+        export_along = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataND method export_along: " + str(export_along)
+                )
+            )
+        )
+    else:
+        export_along = export_along
     # cf Methods.DataND.extract_slices
     if isinstance(extract_slices, ImportError):
         extract_slices = property(
@@ -232,36 +246,6 @@ class DataND(Data):
         )
     else:
         extract_slices_fft = extract_slices_fft
-    # cf Methods.DataND.get_field
-    if isinstance(get_field, ImportError):
-        get_field = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use DataND method get_field: " + str(get_field))
-            )
-        )
-    else:
-        get_field = get_field
-    # cf Methods.DataND.rebuild_symmetries
-    if isinstance(rebuild_symmetries, ImportError):
-        rebuild_symmetries = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method rebuild_symmetries: "
-                    + str(rebuild_symmetries)
-                )
-            )
-        )
-    else:
-        rebuild_symmetries = rebuild_symmetries
-    # cf Methods.DataND.interpolate
-    if isinstance(interpolate, ImportError):
-        interpolate = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use DataND method interpolate: " + str(interpolate))
-            )
-        )
-    else:
-        interpolate = interpolate
     # cf Methods.DataND.get_along
     if isinstance(get_along, ImportError):
         get_along = property(
@@ -271,6 +255,46 @@ class DataND(Data):
         )
     else:
         get_along = get_along
+    # cf Methods.DataND.get_axes
+    if isinstance(get_axes, ImportError):
+        get_axes = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use DataND method get_axes: " + str(get_axes))
+            )
+        )
+    else:
+        get_axes = get_axes
+    # cf Methods.DataND.get_data_along
+    if isinstance(get_data_along, ImportError):
+        get_data_along = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataND method get_data_along: " + str(get_data_along)
+                )
+            )
+        )
+    else:
+        get_data_along = get_data_along
+    # cf Methods.DataND.get_field
+    if isinstance(get_field, ImportError):
+        get_field = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use DataND method get_field: " + str(get_field))
+            )
+        )
+    else:
+        get_field = get_field
+    # cf Methods.DataND.get_harmonics
+    if isinstance(get_harmonics, ImportError):
+        get_harmonics = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataND method get_harmonics: " + str(get_harmonics)
+                )
+            )
+        )
+    else:
+        get_harmonics = get_harmonics
     # cf Methods.DataND.get_magnitude_along
     if isinstance(get_magnitude_along, ImportError):
         get_magnitude_along = property(
@@ -294,26 +318,6 @@ class DataND(Data):
         )
     else:
         get_phase_along = get_phase_along
-    # cf Methods.DataND.get_harmonics
-    if isinstance(get_harmonics, ImportError):
-        get_harmonics = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method get_harmonics: " + str(get_harmonics)
-                )
-            )
-        )
-    else:
-        get_harmonics = get_harmonics
-    # cf Methods.DataND._set_values
-    if isinstance(_set_values, ImportError):
-        _set_values = property(
-            fget=lambda x: raise_(
-                ImportError("Can't use DataND method _set_values: " + str(_set_values))
-            )
-        )
-    else:
-        _set_values = _set_values
     # cf Methods.DataND.has_period
     if isinstance(has_period, ImportError):
         has_period = property(
@@ -323,26 +327,15 @@ class DataND(Data):
         )
     else:
         has_period = has_period
-    # cf Methods.DataND.get_axes
-    if isinstance(get_axes, ImportError):
-        get_axes = property(
+    # cf Methods.DataND.interpolate
+    if isinstance(interpolate, ImportError):
+        interpolate = property(
             fget=lambda x: raise_(
-                ImportError("Can't use DataND method get_axes: " + str(get_axes))
+                ImportError("Can't use DataND method interpolate: " + str(interpolate))
             )
         )
     else:
-        get_axes = get_axes
-    # cf Methods.DataND.get_data_along
-    if isinstance(get_data_along, ImportError):
-        get_data_along = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use DataND method get_data_along: " + str(get_data_along)
-                )
-            )
-        )
-    else:
-        get_data_along = get_data_along
+        interpolate = interpolate
     # cf Methods.DataND.plot_2D_Data
     if isinstance(plot_2D_Data, ImportError):
         plot_2D_Data = property(
@@ -365,6 +358,29 @@ class DataND(Data):
         )
     else:
         plot_3D_Data = plot_3D_Data
+    # cf Methods.DataND.rebuild_symmetries
+    if isinstance(rebuild_symmetries, ImportError):
+        rebuild_symmetries = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataND method rebuild_symmetries: "
+                    + str(rebuild_symmetries)
+                )
+            )
+        )
+    else:
+        rebuild_symmetries = rebuild_symmetries
+    # cf Methods.DataND.set_Ftparameters
+    if isinstance(set_Ftparameters, ImportError):
+        set_Ftparameters = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use DataND method set_Ftparameters: " + str(set_Ftparameters)
+                )
+            )
+        )
+    else:
+        set_Ftparameters = set_Ftparameters
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -462,6 +478,38 @@ class DataND(Data):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Data
+        diff_list.extend(super(DataND, self).compare(other, name=name))
+        if (other.axes is None and self.axes is not None) or (
+            other.axes is not None and self.axes is None
+        ):
+            diff_list.append(name + ".axes None mismatch")
+        elif self.axes is None:
+            pass
+        elif len(other.axes) != len(self.axes):
+            diff_list.append("len(" + name + ".axes)")
+        else:
+            for ii in range(len(other.axes)):
+                diff_list.extend(
+                    self.axes[ii].compare(
+                        other.axes[ii], name=name + ".axes[" + str(ii) + "]"
+                    )
+                )
+        if other._FTparameters != self._FTparameters:
+            diff_list.append(name + ".FTparameters")
+        if not array_equal(other.values, self.values):
+            diff_list.append(name + ".values")
+        if other._is_real != self._is_real:
+            diff_list.append(name + ".is_real")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -479,11 +527,15 @@ class DataND(Data):
         S += getsizeof(self.is_real)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Data
-        DataND_dict = super(DataND, self).as_dict()
+        DataND_dict = super(DataND, self).as_dict(**kwargs)
         if self.axes is None:
             DataND_dict["axes"] = None
         else:
