@@ -8,7 +8,16 @@ from SciDataTool.Functions.Plot import (
     COLORS,
     LINESTYLES,
 )
-from numpy import squeeze, split, array, where, unique, max as np_max, array2string
+from numpy import (
+    squeeze,
+    split,
+    array,
+    where,
+    unique,
+    max as np_max,
+    array2string,
+    insert,
+)
 
 
 def plot_2D_Data(
@@ -205,7 +214,10 @@ def plot_2D_Data(
                 main_axis_name = name
             elif axis.unit in norm_dict:
                 xlabel = norm_dict[axis.unit]
-                main_axis_name = axis.unit
+                if axis.unit == "Hz":
+                    main_axis_name = "frequency"
+                else:
+                    main_axis_name = axis.unit
             else:
                 unit = axis.unit
                 xlabel = name.capitalize() + " [" + unit + "]"
@@ -227,7 +239,7 @@ def plot_2D_Data(
                 unit = axis.unit
 
             axis_str = array2string(
-                result_0[axis.name], formatter={"float_kind": "{:.2g}".format}
+                result_0[axis.name], formatter={"float_kind": "{:.3g}".format}
             ).replace(" ", ", ")
             if len(result_0[axis.name]) == 1:
                 axis_str = axis_str.strip("[]")
@@ -242,7 +254,7 @@ def plot_2D_Data(
             + "="
             + array2string(
                 axes_dict_other[axis_name][0],
-                formatter={"float_kind": "{:.2g}".format},
+                formatter={"float_kind": "{:.3g}".format},
             ).replace(" ", ", ")
             + " ["
             + axes_dict_other[axis_name][1]
@@ -257,7 +269,7 @@ def plot_2D_Data(
 
     # Remove last coma due to title3 or title4
     title = title.rstrip(", ")
-    
+
     # Remove dimless and quotes
     title = title.replace("[]", "")
     title = title.replace("'", "")
@@ -302,7 +314,7 @@ def plot_2D_Data(
                         else legend_list[i]
                         + axis.name
                         + "="
-                        + "%.2g" % axis.values.tolist()[j]
+                        + "%.3g" % axis.values.tolist()[j]
                         + " "
                         + unit
                         for j in range(n_curves)
@@ -338,7 +350,7 @@ def plot_2D_Data(
             for ind, y in enumerate(Ydatas[0])
             if abs(y) > abs(0.02 * np_max(Ydatas[0]))
         ]
-        xticks = unique(freqs[indices])
+        xticks = unique(insert(0, 0, freqs[indices]))
 
         if is_auto_range:
             if len(xticks) > 0:
@@ -422,6 +434,7 @@ def plot_2D_Data(
             is_disp_title=is_disp_title,
             is_grid=is_grid,
             xticks=xticks,
+            barwidth=barwidth,
             linestyle_list=linestyle_list,
             linewidth_list=linewidth_list,
             save_path=save_path,
